@@ -17,9 +17,9 @@ Synchronous::Synchronous(uint timeout)
   if (timeout) _timer.start(timeout, true);
 }
 
-// uplifted from kdelibs...
-void qt_enter_modal(TQWidget *widget);
-void qt_leave_modal(TQWidget *widget);
+// uplifted from tdelibs...
+void tqt_enter_modal(TQWidget *widget);
+void tqt_leave_modal(TQWidget *widget);
 
 bool Synchronous::enterLoop()
 {
@@ -27,11 +27,11 @@ bool Synchronous::enterLoop()
   if ( tqApp->type()!=TQApplication::Tty ) {
     dummy = new TQWidget(0, 0, WType_Dialog | WShowModal);
     dummy->setFocusPolicy(TQ_NoFocus);
-    qt_enter_modal(dummy);
+    tqt_enter_modal(dummy);
   }
   TQApplication::eventLoop()->enterLoop();
   if ( tqApp->type()!=TQApplication::Tty ) {
-    qt_leave_modal(dummy);
+    tqt_leave_modal(dummy);
     delete dummy;
   }
   return _timer.isActive();
