@@ -10,15 +10,15 @@ class TQProcess;
 class Q3Process;
 #endif
 
-class KProcess : public TQObject
+class TDEProcess : public TQObject
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
-  KProcess(TQObject *parent = 0, const char *name = 0);
+  TDEProcess(TQObject *parent = 0, const char *name = 0);
   void clearArguments() { _arguments.clear(); }
-  KProcess &operator<< (const TQString &arg) { _arguments += arg; return *this; }
-  KProcess &operator<< (const TQStringList &args) { _arguments += args; return *this; }
+  TDEProcess &operator<< (const TQString &arg) { _arguments += arg; return *this; }
+  TDEProcess &operator<< (const TQStringList &args) { _arguments += args; return *this; }
   TQStringList args() const { return _arguments; }
   void setEnvironment(const TQString &name, const TQString &value) { _environment += name + "=" + value; }
   bool start();
@@ -31,9 +31,9 @@ public:
   void setUseShell(bool useShell);
 
 signals:
-  void processExited(KProcess *process);
-  void receivedStdout(KProcess *process, char *buffer, int len);
-  void receivedStderr(KProcess *process, char *buffer, int len);
+  void processExited(TDEProcess *process);
+  void receivedStdout(TDEProcess *process, char *buffer, int len);
+  void receivedStderr(TDEProcess *process, char *buffer, int len);
 
 private slots:
   void processExitedSlot();
