@@ -10,7 +10,7 @@
 
 #include <tqlayout.h>
 #include <tqlabel.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include "mem24_memory_editor.h"
 
