@@ -15,10 +15,10 @@
 #include <tqtimer.h>
 #include <tqheader.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kaction.h>
-#include <kapplication.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
 
 #include "project.h"
 #include "project_wizard.h"
@@ -67,7 +67,7 @@ void ProjectManager::View::init()
   clear();
   _rootItem  = new RootItem(this);
   setCurrentItem(_rootItem);
-  KListViewItem *item = new RegisterItem(headerItem(DeviceGroup));
+  TDEListViewItem *item = new RegisterItem(headerItem(DeviceGroup));
   ensureItemVisible(item);
   _deviceItem = new DeviceItem(headerItem(DeviceGroup));
   ensureItemVisible(_deviceItem);
@@ -164,7 +164,7 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
     if ( _project==0 || Main::toolGroup().linkerScriptType()==PURL::Nb_FileTypes ) return;
     pop.insertTitle(i18n("Linker Script"));
     pop.insertItem("piklab_addfile", i18n("Set Custom..."));
-    if ( !_project->customLinkerScript().isEmpty() ) pop.insertItem("editdelete", i18n("Set Default"));
+    if ( !_project->customLinkerScript().isEmpty() ) pop.insertItem("edit-delete", i18n("Set Default"));
     switch( pop.exec(p) ) {
       case 1: {
         PURL::Url url = PURL::getOpenUrl(":custom_linker_script", PURL::filter(Main::toolGroup().linkerScriptType()), this, i18n("Select Linker Script"));
@@ -189,12 +189,12 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
     } else {
       pop.insertTitle(i18n("Project"));
       pop.insertItem("configure", i18n("Options..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(configureProject()));
-      pop.insertItem("find", i18n("Find Files..."),   TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(runKfind()));
+      pop.insertItem("edit-find", i18n("Find Files..."),   TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(runKfind()));
       pop.insertSeparator();
       pop.insertItem("piklab_compile", i18n("Build Project"), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(buildProject()));
       pop.insertItem("trashcan_empty", i18n("Clean Project"), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(cleanBuild()));
       pop.insertSeparator();
-      pop.insertItem("filenew", i18n("New Source File..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newSourceFile()));
+      pop.insertItem("document-new", i18n("New Source File..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newSourceFile()));
       pop.insertItem("piklab_addfile", i18n("Add Source Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertSourceFiles()));
       pop.insertItem("piklab_addfile", i18n("Add Object Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertObjectFiles()));
       if ( Main::currentEditor() ) pop.insertItem("piklab_addcurrentfile", i18n("Add Current File"), TQT_TQOBJECT(this), TQT_SLOT(insertCurrentFile()));
@@ -205,7 +205,7 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
     FileItem *fi = static_cast<FileItem *>(item);
     if ( isExternalFile(fi->url()) ) return;
     pop.insertTitle(item->text(0));
-    pop.insertItem("editdelete", i18n("Remove From Project"));
+    pop.insertItem("edit-delete", i18n("Remove From Project"));
     if ( pop.exec(p)==1 ) removeFile(fi->url());
   } else if ( item->rtti()==HeaderRtti ) {
     if ( _project==0 ) return;
@@ -215,11 +215,11 @@ void ProjectManager::View::contextMenu(TQListViewItem *item, const TQPoint &p, i
       pop.exec(p);
     } else if ( group==SourceGroup || group==HeaderGroup ) {
       pop.insertTitle(i18n("Sources"));
-      pop.insertItem("filenew", i18n("New File..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newSourceFile()));
+      pop.insertItem("document-new", i18n("New File..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(newSourceFile()));
       pop.insertItem("piklab_addfile", i18n("Add Source Files..."), TQT_TQOBJECT(this), TQT_SLOT(insertSourceFiles()));
       pop.exec(p);
     } else if ( group==DeviceGroup ) {
-      pop.insertItem("filenew", i18n("Select Device..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(showDeviceInfo()));
+      pop.insertItem("document-new", i18n("Select Device..."), TQT_TQOBJECT(&Main::toplevel()), TQT_SLOT(showDeviceInfo()));
       pop.exec(p);
     }
   }
@@ -524,7 +524,7 @@ bool ProjectManager::View::openProject(const PURL::Url &url)
   if ( url.isEmpty() ) return false;
   bool reload = ( _project && _project->url()==url );
   if ( reload && !MessageBox::askContinue(i18n("Project already loaded. Reload?"), i18n("Reload")) ) return false;
-  static_cast< KRecentFilesAction *>(Main::action("project_open_recent"))->removeURL(url.kurl());
+  static_cast< TDERecentFilesAction *>(Main::action("project_open_recent"))->removeURL(url.kurl());
   Project *p = new Project(url);
   TQString error;
   if ( !p->load(error) ) {
@@ -538,7 +538,7 @@ bool ProjectManager::View::openProject(const PURL::Url &url)
   for(it=files.begin(); it!=files.end(); ++it) addFile(*it, (*it).fileType(), Intrinsic);
   _projectData.type = PURL::Project;
   _projectData.externals.clear();
-  static_cast<KRecentFilesAction *>(Main::action("project_open_recent"))->addURL(url.kurl());
+  static_cast<TDERecentFilesAction *>(Main::action("project_open_recent"))->addURL(url.kurl());
   files = _project->openedFiles();
   for(it = files.begin(); it!=files.end(); ++it) Main::editorManager().openFile(*it);
   Register::list().init();
