@@ -52,11 +52,11 @@ const CLI::CommandData CLI::NORMAL_COMMAND_DATA[] = {
   { 0, NoCommandProperty, 0 }
 };
 
-const KCmdLineOptions CLI::OPTIONS[] = {
+const TDECmdLineOptions CLI::OPTIONS[] = {
   { "r",              0, 0 },
   { "range <name>",   I18N_NOOP("Memory range to operate on."), 0 },
   { "range-list",     I18N_NOOP("Return the list of memory ranges."), 0 },
-  KCmdLineLastOption
+  TDECmdLineLastOption
 };
 
 //-----------------------------------------------------------------------------
